@@ -40,6 +40,9 @@ class Doc:
         # 获取模型信息
         for item in fields:
             cur_fields[item.column] = {
+                # 字段注释
+                'comment': item.help_text if item.help_text else item.verbose_name,
+                # 字段默认值
                 'default': item.get_default(),
                 # 获取关联表
                 'relation_table_name': item.related_model._meta.db_table if item.is_relation else ''
